Class: ActiveRecord::ConnectionAdapters::PostgreSQLAdapter
- Inherits:
-
AbstractAdapter
- Object
- AbstractAdapter
- ActiveRecord::ConnectionAdapters::PostgreSQLAdapter
- Defined in:
- lib/so2pg.rb
Instance Method Summary collapse
-
#uuid ⇒ Object
Extends the adapter to include support for a uuid type.
Instance Method Details
#uuid ⇒ Object
Extends the adapter to include support for a uuid type. This is required by the importer (see SO2DB::Importer for more information). For PostgreSQL, simply use the native ‘uuid’ type (for MySQL, use something a bit more contrived, like CHAR(16)).
32 33 34 |
# File 'lib/so2pg.rb', line 32 def uuid return 'uuid', {} end |